@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use English qw< -no_match_vars >;
 use Data::Dumper;
-our $VERSION = '0.734';
+our $VERSION = '0.736';
 
 use Template::Perlish;
 use Log::Log4perl::Tiny qw< :easy :dead_if_first get_logger >;
@@ -101,11 +101,13 @@ sub log_helper {
 } ## end sub log_helper
 
 sub tubify {
+   my $opts = {};
+   $opts = shift(@_) if (@_ && ref($_[0]) eq 'HASH');
    map {
       my $ref = ref $_;
       ($ref eq 'CODE')
         ? $_
-        : tube(($ref eq 'ARRAY') ? @$_ : $_)
+        : tube($opts, ($ref eq 'ARRAY') ? @$_ : $_)
    } grep { $_ } @_;
 } ## end sub tubify
 
