@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use English qw< -no_match_vars >;
 use Exporter 'import';
-our $VERSION = '0.734';
+our $VERSION = '0.736';
 
 use Log::Log4perl::Tiny qw< :easy :dead_if_first >;
 
@@ -325,6 +325,11 @@ sub read_file_maybe {
 sub resolve_module {
    my ($module, $prefix) = @_;
 
+   # Force a first character transforming from new interface if after 0.734
+   if ($Data::Tubes::API_VERSION gt '0.734') {
+      $module = '+' . $module unless $module =~ s{^[+^]}{!}mxs;
+   }
+
    my ($first) = substr $module, 0, 1;
    return substr $module, 1 if $first eq '!';
 
@@ -337,7 +342,7 @@ sub resolve_module {
    }
    return $module unless defined $prefix;
    return $prefix . '::' . $module;
-} ## end sub resolve_module
+}
 
 sub shorter_sub_names {
    my $stash = shift(@_) . '::';
@@ -429,8 +434,11 @@ sub trim {
 }
 
 sub tube {
+   my $opts = {};
+   $opts = shift(@_) if (@_ && ref($_[0]) eq 'HASH');
+   my @prefix = exists($opts->{prefix}) ? ($opts->{prefix}) : ();
    my $locator = shift;
-   return load_sub($locator)->(@_);
+   return load_sub($locator, @prefix)->(@_);
 }
 
 sub unzip {
